@@ -38,7 +38,7 @@ AFTER_BOOTLOADER_SKIP_BYTE_DELAY = 2.5
 NETWORK_COMMISSIONING_TIMEOUT = 30
 BOOTLOADER_PIN_TOGGLE_DELAY = 0.15
 CONNECT_PING_TIMEOUT = 0.50
-CONNECT_PROBE_TIMEOUT = 5.0
+CONNECT_PROBE_TIMEOUT = 10
 
 
 class ZNP:
@@ -468,27 +468,6 @@ class ZNP:
         """
 
         async def ping_task():
-            # First, just try pinging
-            try:
-                async with async_timeout.timeout(CONNECT_PING_TIMEOUT):
-                    return await self.request(c.SYS.Ping.Req())
-            except asyncio.TimeoutError:
-                pass
-
-            # If that doesn't work, send the bootloader skip bytes and try again.
-            # Sending a bunch at a time fixes UART issues when the radio was previously
-            # probed with another library at a different baudrate.
-            self._uart.write(256 * bytes([c.ubl.BootloaderRunMode.FORCE_RUN]))
-
-            await asyncio.sleep(AFTER_BOOTLOADER_SKIP_BYTE_DELAY)
-
-            try:
-                async with async_timeout.timeout(CONNECT_PING_TIMEOUT):
-                    return await self.request(c.SYS.Ping.Req())
-            except asyncio.TimeoutError:
-                pass
-
-            # This is normally done just for Slaesh's CC2652RB stick
             LOGGER.debug("Toggling RTS/DTR pins to skip bootloader or reset chip")
 
             # The default sequence is DTR=false and RTS toggling false/true/false
@@ -499,9 +478,28 @@ class ZNP:
                 self._uart.set_dtr_rts(dtr=dtr, rts=rts)
                 await asyncio.sleep(BOOTLOADER_PIN_TOGGLE_DELAY)
 
-            # At this point we have nothing else to try, don't catch the timeout
-            async with async_timeout.timeout(CONNECT_PING_TIMEOUT):
-                return await self.request(c.SYS.Ping.Req())
+            # First, just try pinging
+            try:
+                async with async_timeout.timeout(CONNECT_PING_TIMEOUT):
+                    return await self.request(c.SYS.Ping.Req())
+            except asyncio.TimeoutError:
+                pass
+
+            # If that doesn't work, send the bootloader skip bytes and try again.
+            # Sending a bunch at a time fixes UART issues when the radio was previously
+            # probed with another library at a different baudrate.
+            LOGGER.debug("Sending CC253x bootloader skip bytes")
+            self._uart.write(256 * bytes([c.ubl.BootloaderRunMode.FORCE_RUN]))
+
+            await asyncio.sleep(AFTER_BOOTLOADER_SKIP_BYTE_DELAY)
+
+            # At this point we have nothing left to try
+            while True:
+                try:
+                    async with async_timeout.timeout(2 * CONNECT_PING_TIMEOUT):
+                        return await self.request(c.SYS.Ping.Req())
+                except asyncio.TimeoutError:
+                    pass
 
         async with self.capture_responses([CatchAllResponse()]) as responses:
             ping_task = asyncio.create_task(ping_task())
